# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['RequestSettingOrganizationArgs', 'RequestSettingOrganization']

@pulumi.input_type
class RequestSettingOrganizationArgs:
    def __init__(__self__, *,
                 id_property: pulumi.Input[_builtins.str],
                 subprocessors_acknowledged: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a RequestSettingOrganization resource.
        :param pulumi.Input[_builtins.str] id_property: Request condition id.
        :param pulumi.Input[_builtins.bool] subprocessors_acknowledged: Whether a customer has acknowledged Access Requests subprocessors.
        """
        pulumi.set(__self__, "id_property", id_property)
        if subprocessors_acknowledged is not None:
            pulumi.set(__self__, "subprocessors_acknowledged", subprocessors_acknowledged)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Input[_builtins.str]:
        """
        Request condition id.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "id_property", value)

    @_builtins.property
    @pulumi.getter(name="subprocessorsAcknowledged")
    def subprocessors_acknowledged(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether a customer has acknowledged Access Requests subprocessors.
        """
        return pulumi.get(self, "subprocessors_acknowledged")

    @subprocessors_acknowledged.setter
    def subprocessors_acknowledged(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "subprocessors_acknowledged", value)


@pulumi.input_type
class _RequestSettingOrganizationState:
    def __init__(__self__, *,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 subprocessors_acknowledged: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering RequestSettingOrganization resources.
        :param pulumi.Input[_builtins.str] id_property: Request condition id.
        :param pulumi.Input[_builtins.bool] subprocessors_acknowledged: Whether a customer has acknowledged Access Requests subprocessors.
        """
        if id_property is not None:
            pulumi.set(__self__, "id_property", id_property)
        if subprocessors_acknowledged is not None:
            pulumi.set(__self__, "subprocessors_acknowledged", subprocessors_acknowledged)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Request condition id.
        """
        return pulumi.get(self, "id_property")

    @id_property.setter
    def id_property(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id_property", value)

    @_builtins.property
    @pulumi.getter(name="subprocessorsAcknowledged")
    def subprocessors_acknowledged(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether a customer has acknowledged Access Requests subprocessors.
        """
        return pulumi.get(self, "subprocessors_acknowledged")

    @subprocessors_acknowledged.setter
    def subprocessors_acknowledged(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "subprocessors_acknowledged", value)


@pulumi.type_token("okta:index/requestSettingOrganization:RequestSettingOrganization")
class RequestSettingOrganization(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 subprocessors_acknowledged: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Manages request settings. This resource allows you to read and configure an Okta [request-setting](https://developer.okta.com/docs/api/iga/openapi/governance.requests.admin.v2/tag/Request-Settings/#tag/Request-Settings/operation/updateOrgRequestSettingsV2).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.RequestCondition("example",
            resource_id="<resource_id>",
            approval_sequence_id="<approval_sequence_id>",
            name="<name>",
            access_scope_settings={
                "type": "RESOURCE_DEFAULT",
            },
            requester_settings={
                "type": "EVERYONE",
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/requestSettingOrganization:RequestSettingOrganization example "default"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] id_property: Request condition id.
        :param pulumi.Input[_builtins.bool] subprocessors_acknowledged: Whether a customer has acknowledged Access Requests subprocessors.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RequestSettingOrganizationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages request settings. This resource allows you to read and configure an Okta [request-setting](https://developer.okta.com/docs/api/iga/openapi/governance.requests.admin.v2/tag/Request-Settings/#tag/Request-Settings/operation/updateOrgRequestSettingsV2).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.RequestCondition("example",
            resource_id="<resource_id>",
            approval_sequence_id="<approval_sequence_id>",
            name="<name>",
            access_scope_settings={
                "type": "RESOURCE_DEFAULT",
            },
            requester_settings={
                "type": "EVERYONE",
            })
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/requestSettingOrganization:RequestSettingOrganization example "default"
        ```

        :param str resource_name: The name of the resource.
        :param RequestSettingOrganizationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RequestSettingOrganizationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 id_property: Optional[pulumi.Input[_builtins.str]] = None,
                 subprocessors_acknowledged: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RequestSettingOrganizationArgs.__new__(RequestSettingOrganizationArgs)

            if id_property is None and not opts.urn:
                raise TypeError("Missing required property 'id_property'")
            __props__.__dict__["id_property"] = id_property
            __props__.__dict__["subprocessors_acknowledged"] = subprocessors_acknowledged
        super(RequestSettingOrganization, __self__).__init__(
            'okta:index/requestSettingOrganization:RequestSettingOrganization',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            id_property: Optional[pulumi.Input[_builtins.str]] = None,
            subprocessors_acknowledged: Optional[pulumi.Input[_builtins.bool]] = None) -> 'RequestSettingOrganization':
        """
        Get an existing RequestSettingOrganization resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] id_property: Request condition id.
        :param pulumi.Input[_builtins.bool] subprocessors_acknowledged: Whether a customer has acknowledged Access Requests subprocessors.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RequestSettingOrganizationState.__new__(_RequestSettingOrganizationState)

        __props__.__dict__["id_property"] = id_property
        __props__.__dict__["subprocessors_acknowledged"] = subprocessors_acknowledged
        return RequestSettingOrganization(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="idProperty")
    def id_property(self) -> pulumi.Output[_builtins.str]:
        """
        Request condition id.
        """
        return pulumi.get(self, "id_property")

    @_builtins.property
    @pulumi.getter(name="subprocessorsAcknowledged")
    def subprocessors_acknowledged(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether a customer has acknowledged Access Requests subprocessors.
        """
        return pulumi.get(self, "subprocessors_acknowledged")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetSecurityEventsProviderResult',
    'AwaitableGetSecurityEventsProviderResult',
    'get_security_events_provider',
    'get_security_events_provider_output',
]

@pulumi.output_type
class GetSecurityEventsProviderResult:
    """
    A collection of values returned by getSecurityEventsProvider.
    """
    def __init__(__self__, id=None, is_enabled=None, name=None, settings=None, status=None, type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_enabled and not isinstance(is_enabled, str):
            raise TypeError("Expected argument 'is_enabled' to be a str")
        pulumi.set(__self__, "is_enabled", is_enabled)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if settings and not isinstance(settings, dict):
            raise TypeError("Expected argument 'settings' to be a dict")
        pulumi.set(__self__, "settings", settings)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of this instance.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> _builtins.str:
        """
        Whether or not the Security Events Provider is enabled.
        """
        return pulumi.get(self, "is_enabled")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the Security Events Provider instance.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def settings(self) -> Optional['outputs.GetSecurityEventsProviderSettingsResult']:
        return pulumi.get(self, "settings")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Indicates whether the Security Events Provider is active or not.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The application type of the Security Events Provider.
        """
        return pulumi.get(self, "type")


class AwaitableGetSecurityEventsProviderResult(GetSecurityEventsProviderResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecurityEventsProviderResult(
            id=self.id,
            is_enabled=self.is_enabled,
            name=self.name,
            settings=self.settings,
            status=self.status,
            type=self.type)


def get_security_events_provider(id: Optional[_builtins.str] = None,
                                 settings: Optional[Union['GetSecurityEventsProviderSettingsArgs', 'GetSecurityEventsProviderSettingsArgsDict']] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecurityEventsProviderResult:
    """
    Get information about a Security Events Provider instance for signal ingestion.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_security_events_provider(id="<security_events_provider_id>")
    ```


    :param _builtins.str id: The unique identifier of this instance.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['settings'] = settings
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getSecurityEventsProvider:getSecurityEventsProvider', __args__, opts=opts, typ=GetSecurityEventsProviderResult).value

    return AwaitableGetSecurityEventsProviderResult(
        id=pulumi.get(__ret__, 'id'),
        is_enabled=pulumi.get(__ret__, 'is_enabled'),
        name=pulumi.get(__ret__, 'name'),
        settings=pulumi.get(__ret__, 'settings'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'))
def get_security_events_provider_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                        settings: Optional[pulumi.Input[Optional[Union['GetSecurityEventsProviderSettingsArgs', 'GetSecurityEventsProviderSettingsArgsDict']]]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSecurityEventsProviderResult]:
    """
    Get information about a Security Events Provider instance for signal ingestion.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_security_events_provider(id="<security_events_provider_id>")
    ```


    :param _builtins.str id: The unique identifier of this instance.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['settings'] = settings
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getSecurityEventsProvider:getSecurityEventsProvider', __args__, opts=opts, typ=GetSecurityEventsProviderResult)
    return __ret__.apply(lambda __response__: GetSecurityEventsProviderResult(
        id=pulumi.get(__response__, 'id'),
        is_enabled=pulumi.get(__response__, 'is_enabled'),
        name=pulumi.get(__response__, 'name'),
        settings=pulumi.get(__response__, 'settings'),
        status=pulumi.get(__response__, 'status'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRequestSettingResourceResult',
    'AwaitableGetRequestSettingResourceResult',
    'get_request_setting_resource',
    'get_request_setting_resource_output',
]

@pulumi.output_type
class GetRequestSettingResourceResult:
    """
    A collection of values returned by getRequestSettingResource.
    """
    def __init__(__self__, id=None, request_on_behalf_of_settings=None, risk_settings=None, valid_access_duration_settings=None, valid_access_scope_settings=None, valid_requester_settings=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if request_on_behalf_of_settings and not isinstance(request_on_behalf_of_settings, dict):
            raise TypeError("Expected argument 'request_on_behalf_of_settings' to be a dict")
        pulumi.set(__self__, "request_on_behalf_of_settings", request_on_behalf_of_settings)
        if risk_settings and not isinstance(risk_settings, dict):
            raise TypeError("Expected argument 'risk_settings' to be a dict")
        pulumi.set(__self__, "risk_settings", risk_settings)
        if valid_access_duration_settings and not isinstance(valid_access_duration_settings, dict):
            raise TypeError("Expected argument 'valid_access_duration_settings' to be a dict")
        pulumi.set(__self__, "valid_access_duration_settings", valid_access_duration_settings)
        if valid_access_scope_settings and not isinstance(valid_access_scope_settings, list):
            raise TypeError("Expected argument 'valid_access_scope_settings' to be a list")
        pulumi.set(__self__, "valid_access_scope_settings", valid_access_scope_settings)
        if valid_requester_settings and not isinstance(valid_requester_settings, list):
            raise TypeError("Expected argument 'valid_requester_settings' to be a list")
        pulumi.set(__self__, "valid_requester_settings", valid_requester_settings)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The resource ID of the request settings to retrieve. This is the unique identifier for the resource in Okta.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="requestOnBehalfOfSettings")
    def request_on_behalf_of_settings(self) -> Optional['outputs.GetRequestSettingResourceRequestOnBehalfOfSettingsResult']:
        """
        Risk settings for the resource.
        """
        return pulumi.get(self, "request_on_behalf_of_settings")

    @_builtins.property
    @pulumi.getter(name="riskSettings")
    def risk_settings(self) -> Optional['outputs.GetRequestSettingResourceRiskSettingsResult']:
        """
        Risk settings for the resource.
        """
        return pulumi.get(self, "risk_settings")

    @_builtins.property
    @pulumi.getter(name="validAccessDurationSettings")
    def valid_access_duration_settings(self) -> Optional['outputs.GetRequestSettingResourceValidAccessDurationSettingsResult']:
        """
        Specifies if and for whom a requester may request the resource for.
        """
        return pulumi.get(self, "valid_access_duration_settings")

    @_builtins.property
    @pulumi.getter(name="validAccessScopeSettings")
    def valid_access_scope_settings(self) -> Optional[Sequence['outputs.GetRequestSettingResourceValidAccessScopeSettingResult']]:
        """
        Risk settings for the resource.
        """
        return pulumi.get(self, "valid_access_scope_settings")

    @_builtins.property
    @pulumi.getter(name="validRequesterSettings")
    def valid_requester_settings(self) -> Optional[Sequence['outputs.GetRequestSettingResourceValidRequesterSettingResult']]:
        """
        Risk settings for the resource.
        """
        return pulumi.get(self, "valid_requester_settings")


class AwaitableGetRequestSettingResourceResult(GetRequestSettingResourceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRequestSettingResourceResult(
            id=self.id,
            request_on_behalf_of_settings=self.request_on_behalf_of_settings,
            risk_settings=self.risk_settings,
            valid_access_duration_settings=self.valid_access_duration_settings,
            valid_access_scope_settings=self.valid_access_scope_settings,
            valid_requester_settings=self.valid_requester_settings)


def get_request_setting_resource(id: Optional[_builtins.str] = None,
                                 request_on_behalf_of_settings: Optional[Union['GetRequestSettingResourceRequestOnBehalfOfSettingsArgs', 'GetRequestSettingResourceRequestOnBehalfOfSettingsArgsDict']] = None,
                                 risk_settings: Optional[Union['GetRequestSettingResourceRiskSettingsArgs', 'GetRequestSettingResourceRiskSettingsArgsDict']] = None,
                                 valid_access_duration_settings: Optional[Union['GetRequestSettingResourceValidAccessDurationSettingsArgs', 'GetRequestSettingResourceValidAccessDurationSettingsArgsDict']] = None,
                                 valid_access_scope_settings: Optional[Sequence[Union['GetRequestSettingResourceValidAccessScopeSettingArgs', 'GetRequestSettingResourceValidAccessScopeSettingArgsDict']]] = None,
                                 valid_requester_settings: Optional[Sequence[Union['GetRequestSettingResourceValidRequesterSettingArgs', 'GetRequestSettingResourceValidRequesterSettingArgsDict']]] = None,
                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRequestSettingResourceResult:
    """
    Retrieves the request settings for a resource.

    ## Example Usage


    :param _builtins.str id: The resource ID of the request settings to retrieve. This is the unique identifier for the resource in Okta.
    :param Union['GetRequestSettingResourceRequestOnBehalfOfSettingsArgs', 'GetRequestSettingResourceRequestOnBehalfOfSettingsArgsDict'] request_on_behalf_of_settings: Risk settings for the resource.
    :param Union['GetRequestSettingResourceRiskSettingsArgs', 'GetRequestSettingResourceRiskSettingsArgsDict'] risk_settings: Risk settings for the resource.
    :param Union['GetRequestSettingResourceValidAccessDurationSettingsArgs', 'GetRequestSettingResourceValidAccessDurationSettingsArgsDict'] valid_access_duration_settings: Specifies if and for whom a requester may request the resource for.
    :param Sequence[Union['GetRequestSettingResourceValidAccessScopeSettingArgs', 'GetRequestSettingResourceValidAccessScopeSettingArgsDict']] valid_access_scope_settings: Risk settings for the resource.
    :param Sequence[Union['GetRequestSettingResourceValidRequesterSettingArgs', 'GetRequestSettingResourceValidRequesterSettingArgsDict']] valid_requester_settings: Risk settings for the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['requestOnBehalfOfSettings'] = request_on_behalf_of_settings
    __args__['riskSettings'] = risk_settings
    __args__['validAccessDurationSettings'] = valid_access_duration_settings
    __args__['validAccessScopeSettings'] = valid_access_scope_settings
    __args__['validRequesterSettings'] = valid_requester_settings
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getRequestSettingResource:getRequestSettingResource', __args__, opts=opts, typ=GetRequestSettingResourceResult).value

    return AwaitableGetRequestSettingResourceResult(
        id=pulumi.get(__ret__, 'id'),
        request_on_behalf_of_settings=pulumi.get(__ret__, 'request_on_behalf_of_settings'),
        risk_settings=pulumi.get(__ret__, 'risk_settings'),
        valid_access_duration_settings=pulumi.get(__ret__, 'valid_access_duration_settings'),
        valid_access_scope_settings=pulumi.get(__ret__, 'valid_access_scope_settings'),
        valid_requester_settings=pulumi.get(__ret__, 'valid_requester_settings'))
def get_request_setting_resource_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                        request_on_behalf_of_settings: Optional[pulumi.Input[Optional[Union['GetRequestSettingResourceRequestOnBehalfOfSettingsArgs', 'GetRequestSettingResourceRequestOnBehalfOfSettingsArgsDict']]]] = None,
                                        risk_settings: Optional[pulumi.Input[Optional[Union['GetRequestSettingResourceRiskSettingsArgs', 'GetRequestSettingResourceRiskSettingsArgsDict']]]] = None,
                                        valid_access_duration_settings: Optional[pulumi.Input[Optional[Union['GetRequestSettingResourceValidAccessDurationSettingsArgs', 'GetRequestSettingResourceValidAccessDurationSettingsArgsDict']]]] = None,
                                        valid_access_scope_settings: Optional[pulumi.Input[Optional[Sequence[Union['GetRequestSettingResourceValidAccessScopeSettingArgs', 'GetRequestSettingResourceValidAccessScopeSettingArgsDict']]]]] = None,
                                        valid_requester_settings: Optional[pulumi.Input[Optional[Sequence[Union['GetRequestSettingResourceValidRequesterSettingArgs', 'GetRequestSettingResourceValidRequesterSettingArgsDict']]]]] = None,
                                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRequestSettingResourceResult]:
    """
    Retrieves the request settings for a resource.

    ## Example Usage


    :param _builtins.str id: The resource ID of the request settings to retrieve. This is the unique identifier for the resource in Okta.
    :param Union['GetRequestSettingResourceRequestOnBehalfOfSettingsArgs', 'GetRequestSettingResourceRequestOnBehalfOfSettingsArgsDict'] request_on_behalf_of_settings: Risk settings for the resource.
    :param Union['GetRequestSettingResourceRiskSettingsArgs', 'GetRequestSettingResourceRiskSettingsArgsDict'] risk_settings: Risk settings for the resource.
    :param Union['GetRequestSettingResourceValidAccessDurationSettingsArgs', 'GetRequestSettingResourceValidAccessDurationSettingsArgsDict'] valid_access_duration_settings: Specifies if and for whom a requester may request the resource for.
    :param Sequence[Union['GetRequestSettingResourceValidAccessScopeSettingArgs', 'GetRequestSettingResourceValidAccessScopeSettingArgsDict']] valid_access_scope_settings: Risk settings for the resource.
    :param Sequence[Union['GetRequestSettingResourceValidRequesterSettingArgs', 'GetRequestSettingResourceValidRequesterSettingArgsDict']] valid_requester_settings: Risk settings for the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['requestOnBehalfOfSettings'] = request_on_behalf_of_settings
    __args__['riskSettings'] = risk_settings
    __args__['validAccessDurationSettings'] = valid_access_duration_settings
    __args__['validAccessScopeSettings'] = valid_access_scope_settings
    __args__['validRequesterSettings'] = valid_requester_settings
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getRequestSettingResource:getRequestSettingResource', __args__, opts=opts, typ=GetRequestSettingResourceResult)
    return __ret__.apply(lambda __response__: GetRequestSettingResourceResult(
        id=pulumi.get(__response__, 'id'),
        request_on_behalf_of_settings=pulumi.get(__response__, 'request_on_behalf_of_settings'),
        risk_settings=pulumi.get(__response__, 'risk_settings'),
        valid_access_duration_settings=pulumi.get(__response__, 'valid_access_duration_settings'),
        valid_access_scope_settings=pulumi.get(__response__, 'valid_access_scope_settings'),
        valid_requester_settings=pulumi.get(__response__, 'valid_requester_settings')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetUserSecurityQuestionsResult',
    'AwaitableGetUserSecurityQuestionsResult',
    'get_user_security_questions',
    'get_user_security_questions_output',
]

@pulumi.output_type
class GetUserSecurityQuestionsResult:
    """
    A collection of values returned by getUserSecurityQuestions.
    """
    def __init__(__self__, id=None, questions=None, user_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if questions and not isinstance(questions, list):
            raise TypeError("Expected argument 'questions' to be a list")
        pulumi.set(__self__, "questions", questions)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def questions(self) -> Sequence['outputs.GetUserSecurityQuestionsQuestionResult']:
        return pulumi.get(self, "questions")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> _builtins.str:
        """
        ID of a Okta User
        """
        return pulumi.get(self, "user_id")


class AwaitableGetUserSecurityQuestionsResult(GetUserSecurityQuestionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserSecurityQuestionsResult(
            id=self.id,
            questions=self.questions,
            user_id=self.user_id)


def get_user_security_questions(user_id: Optional[_builtins.str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserSecurityQuestionsResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example_user = okta.user.User("example",
        first_name="John",
        last_name="Smith",
        login="john.smith@example.com",
        email="john.smith@example.com")
    example = okta.get_user_security_questions_output(user_id=example_user.id)
    ```


    :param _builtins.str user_id: ID of a Okta User
    """
    __args__ = dict()
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getUserSecurityQuestions:getUserSecurityQuestions', __args__, opts=opts, typ=GetUserSecurityQuestionsResult).value

    return AwaitableGetUserSecurityQuestionsResult(
        id=pulumi.get(__ret__, 'id'),
        questions=pulumi.get(__ret__, 'questions'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_user_security_questions_output(user_id: Optional[pulumi.Input[_builtins.str]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUserSecurityQuestionsResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example_user = okta.user.User("example",
        first_name="John",
        last_name="Smith",
        login="john.smith@example.com",
        email="john.smith@example.com")
    example = okta.get_user_security_questions_output(user_id=example_user.id)
    ```


    :param _builtins.str user_id: ID of a Okta User
    """
    __args__ = dict()
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getUserSecurityQuestions:getUserSecurityQuestions', __args__, opts=opts, typ=GetUserSecurityQuestionsResult)
    return __ret__.apply(lambda __response__: GetUserSecurityQuestionsResult(
        id=pulumi.get(__response__, 'id'),
        questions=pulumi.get(__response__, 'questions'),
        user_id=pulumi.get(__response__, 'user_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PushProviderArgs', 'PushProvider']

@pulumi.input_type
class PushProviderArgs:
    def __init__(__self__, *,
                 provider_type: pulumi.Input[_builtins.str],
                 configuration: Optional[pulumi.Input['PushProviderConfigurationArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a PushProvider resource.
        :param pulumi.Input[_builtins.str] provider_type: The type of push provider. Valid values are `APNS` (Apple Push Notification Service) or `FCM` (Firebase Cloud Messaging).
        :param pulumi.Input['PushProviderConfigurationArgs'] configuration: Configuration block for the push provider. The configuration structure depends on the provider type.
        :param pulumi.Input[_builtins.str] name: The display name of the push provider.
        """
        pulumi.set(__self__, "provider_type", provider_type)
        if configuration is not None:
            pulumi.set(__self__, "configuration", configuration)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="providerType")
    def provider_type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of push provider. Valid values are `APNS` (Apple Push Notification Service) or `FCM` (Firebase Cloud Messaging).
        """
        return pulumi.get(self, "provider_type")

    @provider_type.setter
    def provider_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "provider_type", value)

    @_builtins.property
    @pulumi.getter
    def configuration(self) -> Optional[pulumi.Input['PushProviderConfigurationArgs']]:
        """
        Configuration block for the push provider. The configuration structure depends on the provider type.
        """
        return pulumi.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: Optional[pulumi.Input['PushProviderConfigurationArgs']]):
        pulumi.set(self, "configuration", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display name of the push provider.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _PushProviderState:
    def __init__(__self__, *,
                 configuration: Optional[pulumi.Input['PushProviderConfigurationArgs']] = None,
                 last_updated_date: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PushProvider resources.
        :param pulumi.Input['PushProviderConfigurationArgs'] configuration: Configuration block for the push provider. The configuration structure depends on the provider type.
        :param pulumi.Input[_builtins.str] last_updated_date: Timestamp when the push provider was last modified. (Computed)
        :param pulumi.Input[_builtins.str] name: The display name of the push provider.
        :param pulumi.Input[_builtins.str] provider_type: The type of push provider. Valid values are `APNS` (Apple Push Notification Service) or `FCM` (Firebase Cloud Messaging).
        """
        if configuration is not None:
            pulumi.set(__self__, "configuration", configuration)
        if last_updated_date is not None:
            pulumi.set(__self__, "last_updated_date", last_updated_date)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_type is not None:
            pulumi.set(__self__, "provider_type", provider_type)

    @_builtins.property
    @pulumi.getter
    def configuration(self) -> Optional[pulumi.Input['PushProviderConfigurationArgs']]:
        """
        Configuration block for the push provider. The configuration structure depends on the provider type.
        """
        return pulumi.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: Optional[pulumi.Input['PushProviderConfigurationArgs']]):
        pulumi.set(self, "configuration", value)

    @_builtins.property
    @pulumi.getter(name="lastUpdatedDate")
    def last_updated_date(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timestamp when the push provider was last modified. (Computed)
        """
        return pulumi.get(self, "last_updated_date")

    @last_updated_date.setter
    def last_updated_date(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_updated_date", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display name of the push provider.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerType")
    def provider_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of push provider. Valid values are `APNS` (Apple Push Notification Service) or `FCM` (Firebase Cloud Messaging).
        """
        return pulumi.get(self, "provider_type")

    @provider_type.setter
    def provider_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "provider_type", value)


@pulumi.type_token("okta:index/pushProvider:PushProvider")
class PushProvider(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 configuration: Optional[pulumi.Input[Union['PushProviderConfigurationArgs', 'PushProviderConfigurationArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages Okta Push Providers that provide a centralized integration platform to fetch and manage push provider configurations. Okta administrators can use these APIs to provide their push provider credentials, for example from APNs and FCM, so that Okta can send push notifications to their own custom app authenticator applications.

        ## Example Usage

        ### FCM Push Provider

        ```python
        import pulumi
        import pulumi_okta as okta

        fcm_example = okta.PushProvider("fcm_example",
            name="FCM Push Provider",
            provider_type="FCM",
            configuration={
                "fcm_configuration": {
                    "service_account_json": {
                        "type": "service_account",
                        "project_id": "my-firebase-project",
                        "private_key_id": "abc123def456",
                        "private_key": \"\"\"-----BEGIN PRIVATE KEY-----
        MIIEvQIBADANBgkqhkiG9w0BAQEFAASCBKcwggSjAgEAAoIBAQC...
        -----END PRIVATE KEY-----
        \"\"\",
                        "client_email": "firebase-adminsdk-abc123@my-firebase-project.iam.gserviceaccount.com",
                        "client_id": "123456789012345678901",
                        "auth_uri": "https://accounts.google.com/o/oauth2/auth",
                        "token_uri": "https://oauth2.googleapis.com/token",
                        "auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",
                        "client_x509_cert_url": "https://www.googleapis.com/robot/v1/metadata/x509/firebase-adminsdk-abc123%40my-firebase-project.iam.gserviceaccount.com",
                        "file_name": "service-account-key.json",
                    },
                },
            })
        ```

        ### APNS (Apple Push Notification Service) Push Provider

        ```python
        import pulumi
        import pulumi_okta as okta

        apns_example = okta.PushProvider("apns_example",
            name="APNS Push Provider",
            provider_type="APNS",
            configuration={
                "apns_configuration": {
                    "key_id": "ABC123DEFG",
                    "team_id": "DEF123GHIJ",
                    "token_signing_key": \"\"\"-----BEGIN PRIVATE KEY-----
        MIGTAgEAMBMGByqGSM49AgEGCCqGSM49AwEHBHkwdwIBAQQg...
        -----END PRIVATE KEY-----
        \"\"\",
                    "file_name": "AuthKey_ABC123DEFG.p8",
                },
            })
        ```

        ## Import

        Push providers can be imported using their ID:

        ```sh
        $ pulumi import okta:index/pushProvider:PushProvider example <push_provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['PushProviderConfigurationArgs', 'PushProviderConfigurationArgsDict']] configuration: Configuration block for the push provider. The configuration structure depends on the provider type.
        :param pulumi.Input[_builtins.str] name: The display name of the push provider.
        :param pulumi.Input[_builtins.str] provider_type: The type of push provider. Valid values are `APNS` (Apple Push Notification Service) or `FCM` (Firebase Cloud Messaging).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PushProviderArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages Okta Push Providers that provide a centralized integration platform to fetch and manage push provider configurations. Okta administrators can use these APIs to provide their push provider credentials, for example from APNs and FCM, so that Okta can send push notifications to their own custom app authenticator applications.

        ## Example Usage

        ### FCM Push Provider

        ```python
        import pulumi
        import pulumi_okta as okta

        fcm_example = okta.PushProvider("fcm_example",
            name="FCM Push Provider",
            provider_type="FCM",
            configuration={
                "fcm_configuration": {
                    "service_account_json": {
                        "type": "service_account",
                        "project_id": "my-firebase-project",
                        "private_key_id": "abc123def456",
                        "private_key": \"\"\"-----BEGIN PRIVATE KEY-----
        MIIEvQIBADANBgkqhkiG9w0BAQEFAASCBKcwggSjAgEAAoIBAQC...
        -----END PRIVATE KEY-----
        \"\"\",
                        "client_email": "firebase-adminsdk-abc123@my-firebase-project.iam.gserviceaccount.com",
                        "client_id": "123456789012345678901",
                        "auth_uri": "https://accounts.google.com/o/oauth2/auth",
                        "token_uri": "https://oauth2.googleapis.com/token",
                        "auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",
                        "client_x509_cert_url": "https://www.googleapis.com/robot/v1/metadata/x509/firebase-adminsdk-abc123%40my-firebase-project.iam.gserviceaccount.com",
                        "file_name": "service-account-key.json",
                    },
                },
            })
        ```

        ### APNS (Apple Push Notification Service) Push Provider

        ```python
        import pulumi
        import pulumi_okta as okta

        apns_example = okta.PushProvider("apns_example",
            name="APNS Push Provider",
            provider_type="APNS",
            configuration={
                "apns_configuration": {
                    "key_id": "ABC123DEFG",
                    "team_id": "DEF123GHIJ",
                    "token_signing_key": \"\"\"-----BEGIN PRIVATE KEY-----
        MIGTAgEAMBMGByqGSM49AgEGCCqGSM49AwEHBHkwdwIBAQQg...
        -----END PRIVATE KEY-----
        \"\"\",
                    "file_name": "AuthKey_ABC123DEFG.p8",
                },
            })
        ```

        ## Import

        Push providers can be imported using their ID:

        ```sh
        $ pulumi import okta:index/pushProvider:PushProvider example <push_provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param PushProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PushProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 configuration: Optional[pulumi.Input[Union['PushProviderConfigurationArgs', 'PushProviderConfigurationArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PushProviderArgs.__new__(PushProviderArgs)

            __props__.__dict__["configuration"] = configuration
            __props__.__dict__["name"] = name
            if provider_type is None and not opts.urn:
                raise TypeError("Missing required property 'provider_type'")
            __props__.__dict__["provider_type"] = provider_type
            __props__.__dict__["last_updated_date"] = None
        super(PushProvider, __self__).__init__(
            'okta:index/pushProvider:PushProvider',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            configuration: Optional[pulumi.Input[Union['PushProviderConfigurationArgs', 'PushProviderConfigurationArgsDict']]] = None,
            last_updated_date: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            provider_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'PushProvider':
        """
        Get an existing PushProvider resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['PushProviderConfigurationArgs', 'PushProviderConfigurationArgsDict']] configuration: Configuration block for the push provider. The configuration structure depends on the provider type.
        :param pulumi.Input[_builtins.str] last_updated_date: Timestamp when the push provider was last modified. (Computed)
        :param pulumi.Input[_builtins.str] name: The display name of the push provider.
        :param pulumi.Input[_builtins.str] provider_type: The type of push provider. Valid values are `APNS` (Apple Push Notification Service) or `FCM` (Firebase Cloud Messaging).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PushProviderState.__new__(_PushProviderState)

        __props__.__dict__["configuration"] = configuration
        __props__.__dict__["last_updated_date"] = last_updated_date
        __props__.__dict__["name"] = name
        __props__.__dict__["provider_type"] = provider_type
        return PushProvider(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def configuration(self) -> pulumi.Output[Optional['outputs.PushProviderConfiguration']]:
        """
        Configuration block for the push provider. The configuration structure depends on the provider type.
        """
        return pulumi.get(self, "configuration")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedDate")
    def last_updated_date(self) -> pulumi.Output[_builtins.str]:
        """
        Timestamp when the push provider was last modified. (Computed)
        """
        return pulumi.get(self, "last_updated_date")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The display name of the push provider.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerType")
    def provider_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of push provider. Valid values are `APNS` (Apple Push Notification Service) or `FCM` (Firebase Cloud Messaging).
        """
        return pulumi.get(self, "provider_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetApiTokenResult',
    'AwaitableGetApiTokenResult',
    'get_api_token',
    'get_api_token_output',
]

@pulumi.output_type
class GetApiTokenResult:
    """
    A collection of values returned by getApiToken.
    """
    def __init__(__self__, client_name=None, created=None, id=None, name=None, network=None, user_id=None):
        if client_name and not isinstance(client_name, str):
            raise TypeError("Expected argument 'client_name' to be a str")
        pulumi.set(__self__, "client_name", client_name)
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network and not isinstance(network, dict):
            raise TypeError("Expected argument 'network' to be a dict")
        pulumi.set(__self__, "network", network)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="clientName")
    def client_name(self) -> _builtins.str:
        """
        The name of the API token client.
        """
        return pulumi.get(self, "client_name")

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        """
        The date and time the API token was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of the API token.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the API token.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def network(self) -> Optional['outputs.GetApiTokenNetworkResult']:
        """
        The network configuration of the API token.
        """
        return pulumi.get(self, "network")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> _builtins.str:
        """
        The userId of the user who created the API Token.
        """
        return pulumi.get(self, "user_id")


class AwaitableGetApiTokenResult(GetApiTokenResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetApiTokenResult(
            client_name=self.client_name,
            created=self.created,
            id=self.id,
            name=self.name,
            network=self.network,
            user_id=self.user_id)


def get_api_token(id: Optional[_builtins.str] = None,
                  network: Optional[Union['GetApiTokenNetworkArgs', 'GetApiTokenNetworkArgsDict']] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetApiTokenResult:
    """
    Use this data source to retrieve information about an Okta API token.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_api_token(id="00T1fxzubpq2epw11d38")
    ```


    :param _builtins.str id: The unique identifier of the API token.
    :param Union['GetApiTokenNetworkArgs', 'GetApiTokenNetworkArgsDict'] network: The network configuration of the API token.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['network'] = network
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getApiToken:getApiToken', __args__, opts=opts, typ=GetApiTokenResult).value

    return AwaitableGetApiTokenResult(
        client_name=pulumi.get(__ret__, 'client_name'),
        created=pulumi.get(__ret__, 'created'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        network=pulumi.get(__ret__, 'network'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_api_token_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                         network: Optional[pulumi.Input[Optional[Union['GetApiTokenNetworkArgs', 'GetApiTokenNetworkArgsDict']]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetApiTokenResult]:
    """
    Use this data source to retrieve information about an Okta API token.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.get_api_token(id="00T1fxzubpq2epw11d38")
    ```


    :param _builtins.str id: The unique identifier of the API token.
    :param Union['GetApiTokenNetworkArgs', 'GetApiTokenNetworkArgsDict'] network: The network configuration of the API token.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['network'] = network
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getApiToken:getApiToken', __args__, opts=opts, typ=GetApiTokenResult)
    return __ret__.apply(lambda __response__: GetApiTokenResult(
        client_name=pulumi.get(__response__, 'client_name'),
        created=pulumi.get(__response__, 'created'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        network=pulumi.get(__response__, 'network'),
        user_id=pulumi.get(__response__, 'user_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetBrandResult',
    'AwaitableGetBrandResult',
    'get_brand',
    'get_brand_output',
]

@pulumi.output_type
class GetBrandResult:
    """
    A collection of values returned by getBrand.
    """
    def __init__(__self__, brand_id=None, custom_privacy_policy_url=None, id=None, links=None, name=None, remove_powered_by_okta=None):
        if brand_id and not isinstance(brand_id, str):
            raise TypeError("Expected argument 'brand_id' to be a str")
        pulumi.set(__self__, "brand_id", brand_id)
        if custom_privacy_policy_url and not isinstance(custom_privacy_policy_url, str):
            raise TypeError("Expected argument 'custom_privacy_policy_url' to be a str")
        pulumi.set(__self__, "custom_privacy_policy_url", custom_privacy_policy_url)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if links and not isinstance(links, str):
            raise TypeError("Expected argument 'links' to be a str")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if remove_powered_by_okta and not isinstance(remove_powered_by_okta, bool):
            raise TypeError("Expected argument 'remove_powered_by_okta' to be a bool")
        pulumi.set(__self__, "remove_powered_by_okta", remove_powered_by_okta)

    @_builtins.property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> _builtins.str:
        """
        Brand ID
        """
        return pulumi.get(self, "brand_id")

    @_builtins.property
    @pulumi.getter(name="customPrivacyPolicyUrl")
    def custom_privacy_policy_url(self) -> _builtins.str:
        """
        Custom privacy policy URL
        """
        return pulumi.get(self, "custom_privacy_policy_url")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the Brand
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def links(self) -> _builtins.str:
        """
        Link relations for this object - JSON HAL - Discoverable resources related to the brand
        """
        return pulumi.get(self, "links")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Brand name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="removePoweredByOkta")
    def remove_powered_by_okta(self) -> _builtins.bool:
        """
        Removes "Powered by Okta" from the Okta-hosted sign-in page and "© 2021 Okta, Inc." from the Okta End-User Dashboard
        """
        return pulumi.get(self, "remove_powered_by_okta")


class AwaitableGetBrandResult(GetBrandResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBrandResult(
            brand_id=self.brand_id,
            custom_privacy_policy_url=self.custom_privacy_policy_url,
            id=self.id,
            links=self.links,
            name=self.name,
            remove_powered_by_okta=self.remove_powered_by_okta)


def get_brand(brand_id: Optional[_builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBrandResult:
    """
    Get a single Brand from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_brands()
    test_get_brand = okta.get_brand(brand_id=test.brands[0].id)
    default = okta.get_brand(brand_id="default")
    ```


    :param _builtins.str brand_id: Brand ID
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getBrand:getBrand', __args__, opts=opts, typ=GetBrandResult).value

    return AwaitableGetBrandResult(
        brand_id=pulumi.get(__ret__, 'brand_id'),
        custom_privacy_policy_url=pulumi.get(__ret__, 'custom_privacy_policy_url'),
        id=pulumi.get(__ret__, 'id'),
        links=pulumi.get(__ret__, 'links'),
        name=pulumi.get(__ret__, 'name'),
        remove_powered_by_okta=pulumi.get(__ret__, 'remove_powered_by_okta'))
def get_brand_output(brand_id: Optional[pulumi.Input[_builtins.str]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBrandResult]:
    """
    Get a single Brand from Okta.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_brands()
    test_get_brand = okta.get_brand(brand_id=test.brands[0].id)
    default = okta.get_brand(brand_id="default")
    ```


    :param _builtins.str brand_id: Brand ID
    """
    __args__ = dict()
    __args__['brandId'] = brand_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getBrand:getBrand', __args__, opts=opts, typ=GetBrandResult)
    return __ret__.apply(lambda __response__: GetBrandResult(
        brand_id=pulumi.get(__response__, 'brand_id'),
        custom_privacy_policy_url=pulumi.get(__response__, 'custom_privacy_policy_url'),
        id=pulumi.get(__response__, 'id'),
        links=pulumi.get(__response__, 'links'),
        name=pulumi.get(__response__, 'name'),
        remove_powered_by_okta=pulumi.get(__response__, 'remove_powered_by_okta')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetEndUserMyRequestsResult',
    'AwaitableGetEndUserMyRequestsResult',
    'get_end_user_my_requests',
    'get_end_user_my_requests_output',
]

@pulumi.output_type
class GetEndUserMyRequestsResult:
    """
    A collection of values returned by getEndUserMyRequests.
    """
    def __init__(__self__, access_duration=None, created=None, created_by=None, entry_id=None, grant_status=None, granted=None, id=None, last_updated=None, last_updated_by=None, requested=None, requested_by=None, requested_for=None, requester_field_values=None, resolved=None, revocation_scheduled=None, revocation_status=None, revoked=None, risk_assessment=None, status=None):
        if access_duration and not isinstance(access_duration, str):
            raise TypeError("Expected argument 'access_duration' to be a str")
        pulumi.set(__self__, "access_duration", access_duration)
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if entry_id and not isinstance(entry_id, str):
            raise TypeError("Expected argument 'entry_id' to be a str")
        pulumi.set(__self__, "entry_id", entry_id)
        if grant_status and not isinstance(grant_status, str):
            raise TypeError("Expected argument 'grant_status' to be a str")
        pulumi.set(__self__, "grant_status", grant_status)
        if granted and not isinstance(granted, str):
            raise TypeError("Expected argument 'granted' to be a str")
        pulumi.set(__self__, "granted", granted)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_updated and not isinstance(last_updated, str):
            raise TypeError("Expected argument 'last_updated' to be a str")
        pulumi.set(__self__, "last_updated", last_updated)
        if last_updated_by and not isinstance(last_updated_by, str):
            raise TypeError("Expected argument 'last_updated_by' to be a str")
        pulumi.set(__self__, "last_updated_by", last_updated_by)
        if requested and not isinstance(requested, dict):
            raise TypeError("Expected argument 'requested' to be a dict")
        pulumi.set(__self__, "requested", requested)
        if requested_by and not isinstance(requested_by, dict):
            raise TypeError("Expected argument 'requested_by' to be a dict")
        pulumi.set(__self__, "requested_by", requested_by)
        if requested_for and not isinstance(requested_for, dict):
            raise TypeError("Expected argument 'requested_for' to be a dict")
        pulumi.set(__self__, "requested_for", requested_for)
        if requester_field_values and not isinstance(requester_field_values, list):
            raise TypeError("Expected argument 'requester_field_values' to be a list")
        pulumi.set(__self__, "requester_field_values", requester_field_values)
        if resolved and not isinstance(resolved, str):
            raise TypeError("Expected argument 'resolved' to be a str")
        pulumi.set(__self__, "resolved", resolved)
        if revocation_scheduled and not isinstance(revocation_scheduled, str):
            raise TypeError("Expected argument 'revocation_scheduled' to be a str")
        pulumi.set(__self__, "revocation_scheduled", revocation_scheduled)
        if revocation_status and not isinstance(revocation_status, str):
            raise TypeError("Expected argument 'revocation_status' to be a str")
        pulumi.set(__self__, "revocation_status", revocation_status)
        if revoked and not isinstance(revoked, str):
            raise TypeError("Expected argument 'revoked' to be a str")
        pulumi.set(__self__, "revoked", revoked)
        if risk_assessment and not isinstance(risk_assessment, dict):
            raise TypeError("Expected argument 'risk_assessment' to be a dict")
        pulumi.set(__self__, "risk_assessment", risk_assessment)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="accessDuration")
    def access_duration(self) -> _builtins.str:
        return pulumi.get(self, "access_duration")

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.str:
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter(name="entryId")
    def entry_id(self) -> _builtins.str:
        """
        The ID of the catalog entry for which the request was made.
        """
        return pulumi.get(self, "entry_id")

    @_builtins.property
    @pulumi.getter(name="grantStatus")
    def grant_status(self) -> _builtins.str:
        return pulumi.get(self, "grant_status")

    @_builtins.property
    @pulumi.getter
    def granted(self) -> _builtins.str:
        return pulumi.get(self, "granted")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the request to retrieve.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> _builtins.str:
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> _builtins.str:
        return pulumi.get(self, "last_updated_by")

    @_builtins.property
    @pulumi.getter
    def requested(self) -> Optional['outputs.GetEndUserMyRequestsRequestedResult']:
        return pulumi.get(self, "requested")

    @_builtins.property
    @pulumi.getter(name="requestedBy")
    def requested_by(self) -> Optional['outputs.GetEndUserMyRequestsRequestedByResult']:
        return pulumi.get(self, "requested_by")

    @_builtins.property
    @pulumi.getter(name="requestedFor")
    def requested_for(self) -> Optional['outputs.GetEndUserMyRequestsRequestedForResult']:
        return pulumi.get(self, "requested_for")

    @_builtins.property
    @pulumi.getter(name="requesterFieldValues")
    def requester_field_values(self) -> Optional[Sequence['outputs.GetEndUserMyRequestsRequesterFieldValueResult']]:
        """
        The requester input fields and their values from the request.
        """
        return pulumi.get(self, "requester_field_values")

    @_builtins.property
    @pulumi.getter
    def resolved(self) -> _builtins.str:
        return pulumi.get(self, "resolved")

    @_builtins.property
    @pulumi.getter(name="revocationScheduled")
    def revocation_scheduled(self) -> _builtins.str:
        return pulumi.get(self, "revocation_scheduled")

    @_builtins.property
    @pulumi.getter(name="revocationStatus")
    def revocation_status(self) -> _builtins.str:
        return pulumi.get(self, "revocation_status")

    @_builtins.property
    @pulumi.getter
    def revoked(self) -> _builtins.str:
        return pulumi.get(self, "revoked")

    @_builtins.property
    @pulumi.getter(name="riskAssessment")
    def risk_assessment(self) -> Optional['outputs.GetEndUserMyRequestsRiskAssessmentResult']:
        return pulumi.get(self, "risk_assessment")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The current status of the request. Possible values include: `APPROVED`, `CANCELED`, `DENIED`, `EXPIRED`, `PENDING`, `REJECTED`, `SUBMITTED`
        """
        return pulumi.get(self, "status")


class AwaitableGetEndUserMyRequestsResult(GetEndUserMyRequestsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndUserMyRequestsResult(
            access_duration=self.access_duration,
            created=self.created,
            created_by=self.created_by,
            entry_id=self.entry_id,
            grant_status=self.grant_status,
            granted=self.granted,
            id=self.id,
            last_updated=self.last_updated,
            last_updated_by=self.last_updated_by,
            requested=self.requested,
            requested_by=self.requested_by,
            requested_for=self.requested_for,
            requester_field_values=self.requester_field_values,
            resolved=self.resolved,
            revocation_scheduled=self.revocation_scheduled,
            revocation_status=self.revocation_status,
            revoked=self.revoked,
            risk_assessment=self.risk_assessment,
            status=self.status)


def get_end_user_my_requests(entry_id: Optional[_builtins.str] = None,
                             id: Optional[_builtins.str] = None,
                             requested: Optional[Union['GetEndUserMyRequestsRequestedArgs', 'GetEndUserMyRequestsRequestedArgsDict']] = None,
                             requested_by: Optional[Union['GetEndUserMyRequestsRequestedByArgs', 'GetEndUserMyRequestsRequestedByArgsDict']] = None,
                             requested_for: Optional[Union['GetEndUserMyRequestsRequestedForArgs', 'GetEndUserMyRequestsRequestedForArgsDict']] = None,
                             requester_field_values: Optional[Sequence[Union['GetEndUserMyRequestsRequesterFieldValueArgs', 'GetEndUserMyRequestsRequesterFieldValueArgsDict']]] = None,
                             risk_assessment: Optional[Union['GetEndUserMyRequestsRiskAssessmentArgs', 'GetEndUserMyRequestsRiskAssessmentArgsDict']] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndUserMyRequestsResult:
    """
    Get an End User Request from Okta Identity Governance. This data source allows you to retrieve information about existing access requests in the Okta Identity Governance system.

    Use this data source to fetch details about a specific request, including its current status, field values, and other metadata.

    > **Note:** This data source is part of Okta Identity Governance functionality and requires appropriate licensing and configuration.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    # Get a request by its catalog entry ID and request ID
    example = okta.get_end_user_my_requests(entry_id="cen123456789abcdefgh",
        id="reqABCDEFG0123456789")
    pulumi.export("requestStatus", example.status)
    pulumi.export("requestFieldValues", example.requester_field_values)
    ```

    ## Field Type Reference

    ### Field Types and Values

    - **TEXT**: Contains free-form text input in the `value` attribute
    - **SELECT**: Contains single selection value in the `value` attribute
    - **MULTISELECT**: Contains multiple selection values in the `values` attribute (list)
    - **DURATION**: Contains time duration specification in the `value` attribute (e.g., "5 days", "2 weeks")
    - **ISO_DATE**: Contains date specification in ISO format in the `value` attribute
    - **OKTA_USER_ID**: Contains Okta user ID in the `value` attribute

    ### Usage Notes

    - For `MULTISELECT` type fields, the values will be in the `values` attribute as a list
    - For all other field types, the value will be in the `value` attribute as a string
    - The `label` and `type` attributes provide metadata about the field structure
    - Field definitions and requirements are determined by the approval system configuration

    ## Limitations and Considerations

    1. **Read-Only**: This data source only retrieves existing request information and cannot modify requests.

    2. **Identity Governance Licensing**: This data source requires Okta Identity Governance licensing and proper configuration.

    3. **Request Lifecycle**: The data reflects the current state of the request in the approval workflow.

    4. **Field Structure**: The field structure and available types depend on the approval system configuration in Okta Identity Governance.


    :param _builtins.str entry_id: The ID of the catalog entry for which the request was made.
    :param _builtins.str id: The ID of the request to retrieve.
    :param Sequence[Union['GetEndUserMyRequestsRequesterFieldValueArgs', 'GetEndUserMyRequestsRequesterFieldValueArgsDict']] requester_field_values: The requester input fields and their values from the request.
    """
    __args__ = dict()
    __args__['entryId'] = entry_id
    __args__['id'] = id
    __args__['requested'] = requested
    __args__['requestedBy'] = requested_by
    __args__['requestedFor'] = requested_for
    __args__['requesterFieldValues'] = requester_field_values
    __args__['riskAssessment'] = risk_assessment
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getEndUserMyRequests:getEndUserMyRequests', __args__, opts=opts, typ=GetEndUserMyRequestsResult).value

    return AwaitableGetEndUserMyRequestsResult(
        access_duration=pulumi.get(__ret__, 'access_duration'),
        created=pulumi.get(__ret__, 'created'),
        created_by=pulumi.get(__ret__, 'created_by'),
        entry_id=pulumi.get(__ret__, 'entry_id'),
        grant_status=pulumi.get(__ret__, 'grant_status'),
        granted=pulumi.get(__ret__, 'granted'),
        id=pulumi.get(__ret__, 'id'),
        last_updated=pulumi.get(__ret__, 'last_updated'),
        last_updated_by=pulumi.get(__ret__, 'last_updated_by'),
        requested=pulumi.get(__ret__, 'requested'),
        requested_by=pulumi.get(__ret__, 'requested_by'),
        requested_for=pulumi.get(__ret__, 'requested_for'),
        requester_field_values=pulumi.get(__ret__, 'requester_field_values'),
        resolved=pulumi.get(__ret__, 'resolved'),
        revocation_scheduled=pulumi.get(__ret__, 'revocation_scheduled'),
        revocation_status=pulumi.get(__ret__, 'revocation_status'),
        revoked=pulumi.get(__ret__, 'revoked'),
        risk_assessment=pulumi.get(__ret__, 'risk_assessment'),
        status=pulumi.get(__ret__, 'status'))
def get_end_user_my_requests_output(entry_id: Optional[pulumi.Input[_builtins.str]] = None,
                                    id: Optional[pulumi.Input[_builtins.str]] = None,
                                    requested: Optional[pulumi.Input[Optional[Union['GetEndUserMyRequestsRequestedArgs', 'GetEndUserMyRequestsRequestedArgsDict']]]] = None,
                                    requested_by: Optional[pulumi.Input[Optional[Union['GetEndUserMyRequestsRequestedByArgs', 'GetEndUserMyRequestsRequestedByArgsDict']]]] = None,
                                    requested_for: Optional[pulumi.Input[Optional[Union['GetEndUserMyRequestsRequestedForArgs', 'GetEndUserMyRequestsRequestedForArgsDict']]]] = None,
                                    requester_field_values: Optional[pulumi.Input[Optional[Sequence[Union['GetEndUserMyRequestsRequesterFieldValueArgs', 'GetEndUserMyRequestsRequesterFieldValueArgsDict']]]]] = None,
                                    risk_assessment: Optional[pulumi.Input[Optional[Union['GetEndUserMyRequestsRiskAssessmentArgs', 'GetEndUserMyRequestsRiskAssessmentArgsDict']]]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEndUserMyRequestsResult]:
    """
    Get an End User Request from Okta Identity Governance. This data source allows you to retrieve information about existing access requests in the Okta Identity Governance system.

    Use this data source to fetch details about a specific request, including its current status, field values, and other metadata.

    > **Note:** This data source is part of Okta Identity Governance functionality and requires appropriate licensing and configuration.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    # Get a request by its catalog entry ID and request ID
    example = okta.get_end_user_my_requests(entry_id="cen123456789abcdefgh",
        id="reqABCDEFG0123456789")
    pulumi.export("requestStatus", example.status)
    pulumi.export("requestFieldValues", example.requester_field_values)
    ```

    ## Field Type Reference

    ### Field Types and Values

    - **TEXT**: Contains free-form text input in the `value` attribute
    - **SELECT**: Contains single selection value in the `value` attribute
    - **MULTISELECT**: Contains multiple selection values in the `values` attribute (list)
    - **DURATION**: Contains time duration specification in the `value` attribute (e.g., "5 days", "2 weeks")
    - **ISO_DATE**: Contains date specification in ISO format in the `value` attribute
    - **OKTA_USER_ID**: Contains Okta user ID in the `value` attribute

    ### Usage Notes

    - For `MULTISELECT` type fields, the values will be in the `values` attribute as a list
    - For all other field types, the value will be in the `value` attribute as a string
    - The `label` and `type` attributes provide metadata about the field structure
    - Field definitions and requirements are determined by the approval system configuration

    ## Limitations and Considerations

    1. **Read-Only**: This data source only retrieves existing request information and cannot modify requests.

    2. **Identity Governance Licensing**: This data source requires Okta Identity Governance licensing and proper configuration.

    3. **Request Lifecycle**: The data reflects the current state of the request in the approval workflow.

    4. **Field Structure**: The field structure and available types depend on the approval system configuration in Okta Identity Governance.


    :param _builtins.str entry_id: The ID of the catalog entry for which the request was made.
    :param _builtins.str id: The ID of the request to retrieve.
    :param Sequence[Union['GetEndUserMyRequestsRequesterFieldValueArgs', 'GetEndUserMyRequestsRequesterFieldValueArgsDict']] requester_field_values: The requester input fields and their values from the request.
    """
    __args__ = dict()
    __args__['entryId'] = entry_id
    __args__['id'] = id
    __args__['requested'] = requested
    __args__['requestedBy'] = requested_by
    __args__['requestedFor'] = requested_for
    __args__['requesterFieldValues'] = requester_field_values
    __args__['riskAssessment'] = risk_assessment
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getEndUserMyRequests:getEndUserMyRequests', __args__, opts=opts, typ=GetEndUserMyRequestsResult)
    return __ret__.apply(lambda __response__: GetEndUserMyRequestsResult(
        access_duration=pulumi.get(__response__, 'access_duration'),
        created=pulumi.get(__response__, 'created'),
        created_by=pulumi.get(__response__, 'created_by'),
        entry_id=pulumi.get(__response__, 'entry_id'),
        grant_status=pulumi.get(__response__, 'grant_status'),
        granted=pulumi.get(__response__, 'granted'),
        id=pulumi.get(__response__, 'id'),
        last_updated=pulumi.get(__response__, 'last_updated'),
        last_updated_by=pulumi.get(__response__, 'last_updated_by'),
        requested=pulumi.get(__response__, 'requested'),
        requested_by=pulumi.get(__response__, 'requested_by'),
        requested_for=pulumi.get(__response__, 'requested_for'),
        requester_field_values=pulumi.get(__response__, 'requester_field_values'),
        resolved=pulumi.get(__response__, 'resolved'),
        revocation_scheduled=pulumi.get(__response__, 'revocation_scheduled'),
        revocation_status=pulumi.get(__response__, 'revocation_status'),
        revoked=pulumi.get(__response__, 'revoked'),
        risk_assessment=pulumi.get(__response__, 'risk_assessment'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['TrustedServerArgs', 'TrustedServer']

@pulumi.input_type
class TrustedServerArgs:
    def __init__(__self__, *,
                 auth_server_id: pulumi.Input[_builtins.str],
                 trusteds: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        """
        The set of arguments for constructing a TrustedServer resource.
        :param pulumi.Input[_builtins.str] auth_server_id: Authorization server ID
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] trusteds: A list of the authorization server IDs user want to trust
        """
        pulumi.set(__self__, "auth_server_id", auth_server_id)
        pulumi.set(__self__, "trusteds", trusteds)

    @_builtins.property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> pulumi.Input[_builtins.str]:
        """
        Authorization server ID
        """
        return pulumi.get(self, "auth_server_id")

    @auth_server_id.setter
    def auth_server_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "auth_server_id", value)

    @_builtins.property
    @pulumi.getter
    def trusteds(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        A list of the authorization server IDs user want to trust
        """
        return pulumi.get(self, "trusteds")

    @trusteds.setter
    def trusteds(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "trusteds", value)


@pulumi.input_type
class _TrustedServerState:
    def __init__(__self__, *,
                 auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 trusteds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering TrustedServer resources.
        :param pulumi.Input[_builtins.str] auth_server_id: Authorization server ID
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] trusteds: A list of the authorization server IDs user want to trust
        """
        if auth_server_id is not None:
            pulumi.set(__self__, "auth_server_id", auth_server_id)
        if trusteds is not None:
            pulumi.set(__self__, "trusteds", trusteds)

    @_builtins.property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Authorization server ID
        """
        return pulumi.get(self, "auth_server_id")

    @auth_server_id.setter
    def auth_server_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "auth_server_id", value)

    @_builtins.property
    @pulumi.getter
    def trusteds(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of the authorization server IDs user want to trust
        """
        return pulumi.get(self, "trusteds")

    @trusteds.setter
    def trusteds(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "trusteds", value)


@pulumi.type_token("okta:index/trustedServer:TrustedServer")
class TrustedServer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 trusteds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Associated (Trusted) authorization servers allow you to designate a trusted authorization server that you associate with another authorization server.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test1 = okta.auth.Server("test1",
            audiences=["whatever.rise.zone"],
            credentials_rotation_mode="AUTO",
            description="The best way to find out if you can trust somebody is to trust them.",
            name="testAcc-replace_with_uuid")
        test2 = okta.auth.Server("test2",
            audiences=["whatever.rise.zone"],
            credentials_rotation_mode="AUTO",
            description="The best way to find out if you can trust somebody is to trust them.",
            name="testAcc-replace_with_uuid")
        test3 = okta.auth.Server("test3",
            audiences=["whatever.rise.zone"],
            credentials_rotation_mode="AUTO",
            description="The best way to find out if you can trust somebody is to trust them.",
            name="testAcc-replace_with_uuid")
        example = okta.TrustedServer("example",
            auth_server_id=okta_auth_server["test1"]["id"],
            trusteds=[
                okta_auth_server["test2"]["id"],
                okta_auth_server["test3"]["id"],
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auth_server_id: Authorization server ID
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] trusteds: A list of the authorization server IDs user want to trust
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: TrustedServerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Associated (Trusted) authorization servers allow you to designate a trusted authorization server that you associate with another authorization server.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        test1 = okta.auth.Server("test1",
            audiences=["whatever.rise.zone"],
            credentials_rotation_mode="AUTO",
            description="The best way to find out if you can trust somebody is to trust them.",
            name="testAcc-replace_with_uuid")
        test2 = okta.auth.Server("test2",
            audiences=["whatever.rise.zone"],
            credentials_rotation_mode="AUTO",
            description="The best way to find out if you can trust somebody is to trust them.",
            name="testAcc-replace_with_uuid")
        test3 = okta.auth.Server("test3",
            audiences=["whatever.rise.zone"],
            credentials_rotation_mode="AUTO",
            description="The best way to find out if you can trust somebody is to trust them.",
            name="testAcc-replace_with_uuid")
        example = okta.TrustedServer("example",
            auth_server_id=okta_auth_server["test1"]["id"],
            trusteds=[
                okta_auth_server["test2"]["id"],
                okta_auth_server["test3"]["id"],
            ])
        ```

        :param str resource_name: The name of the resource.
        :param TrustedServerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TrustedServerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 trusteds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TrustedServerArgs.__new__(TrustedServerArgs)

            if auth_server_id is None and not opts.urn:
                raise TypeError("Missing required property 'auth_server_id'")
            __props__.__dict__["auth_server_id"] = auth_server_id
            if trusteds is None and not opts.urn:
                raise TypeError("Missing required property 'trusteds'")
            __props__.__dict__["trusteds"] = trusteds
        super(TrustedServer, __self__).__init__(
            'okta:index/trustedServer:TrustedServer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auth_server_id: Optional[pulumi.Input[_builtins.str]] = None,
            trusteds: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'TrustedServer':
        """
        Get an existing TrustedServer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] auth_server_id: Authorization server ID
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] trusteds: A list of the authorization server IDs user want to trust
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TrustedServerState.__new__(_TrustedServerState)

        __props__.__dict__["auth_server_id"] = auth_server_id
        __props__.__dict__["trusteds"] = trusteds
        return TrustedServer(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="authServerId")
    def auth_server_id(self) -> pulumi.Output[_builtins.str]:
        """
        Authorization server ID
        """
        return pulumi.get(self, "auth_server_id")

    @_builtins.property
    @pulumi.getter
    def trusteds(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        A list of the authorization server IDs user want to trust
        """
        return pulumi.get(self, "trusteds")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetAppsResult',
    'AwaitableGetAppsResult',
    'get_apps',
    'get_apps_output',
]

@pulumi.output_type
class GetAppsResult:
    """
    A collection of values returned by getApps.
    """
    def __init__(__self__, active_only=None, apps=None, id=None, include_non_deleted=None, label=None, label_prefix=None, q=None, use_optimization=None):
        if active_only and not isinstance(active_only, bool):
            raise TypeError("Expected argument 'active_only' to be a bool")
        pulumi.set(__self__, "active_only", active_only)
        if apps and not isinstance(apps, list):
            raise TypeError("Expected argument 'apps' to be a list")
        pulumi.set(__self__, "apps", apps)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if include_non_deleted and not isinstance(include_non_deleted, bool):
            raise TypeError("Expected argument 'include_non_deleted' to be a bool")
        pulumi.set(__self__, "include_non_deleted", include_non_deleted)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if label_prefix and not isinstance(label_prefix, str):
            raise TypeError("Expected argument 'label_prefix' to be a str")
        pulumi.set(__self__, "label_prefix", label_prefix)
        if q and not isinstance(q, str):
            raise TypeError("Expected argument 'q' to be a str")
        pulumi.set(__self__, "q", q)
        if use_optimization and not isinstance(use_optimization, bool):
            raise TypeError("Expected argument 'use_optimization' to be a bool")
        pulumi.set(__self__, "use_optimization", use_optimization)

    @_builtins.property
    @pulumi.getter(name="activeOnly")
    def active_only(self) -> Optional[_builtins.bool]:
        """
        Search only active applications.
        """
        return pulumi.get(self, "active_only")

    @_builtins.property
    @pulumi.getter
    def apps(self) -> Sequence['outputs.GetAppsAppResult']:
        """
        The list of applications that match the search criteria.
        """
        return pulumi.get(self, "apps")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="includeNonDeleted")
    def include_non_deleted(self) -> Optional[_builtins.bool]:
        """
        Specifies whether to include non-active, but not deleted apps in the results.
        """
        return pulumi.get(self, "include_non_deleted")

    @_builtins.property
    @pulumi.getter
    def label(self) -> Optional[_builtins.str]:
        """
        Searches for applications whose label or name property matches this value exactly.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter(name="labelPrefix")
    @_utilities.deprecated("""Use `q` instead. This attribute will be removed in a future version.""")
    def label_prefix(self) -> Optional[_builtins.str]:
        """
        Searches for applications whose label or name property begins with this value. **Warning:** This might not work as intended and will be removed in the future release. Use `q` instead.
        """
        return pulumi.get(self, "label_prefix")

    @_builtins.property
    @pulumi.getter
    def q(self) -> Optional[_builtins.str]:
        """
        Searches for apps with name or label properties that starts with the `q` value.
        """
        return pulumi.get(self, "q")

    @_builtins.property
    @pulumi.getter(name="useOptimization")
    def use_optimization(self) -> Optional[_builtins.bool]:
        """
        Specifies whether to use query optimization. If you specify `useOptimization=true` in the request query, the response contains a subset of app instance properties.
        """
        return pulumi.get(self, "use_optimization")


class AwaitableGetAppsResult(GetAppsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAppsResult(
            active_only=self.active_only,
            apps=self.apps,
            id=self.id,
            include_non_deleted=self.include_non_deleted,
            label=self.label,
            label_prefix=self.label_prefix,
            q=self.q,
            use_optimization=self.use_optimization)


def get_apps(active_only: Optional[_builtins.bool] = None,
             include_non_deleted: Optional[_builtins.bool] = None,
             label: Optional[_builtins.str] = None,
             label_prefix: Optional[_builtins.str] = None,
             q: Optional[_builtins.str] = None,
             use_optimization: Optional[_builtins.bool] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAppsResult:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.bool active_only: Search only active applications.
    :param _builtins.bool include_non_deleted: Specifies whether to include non-active, but not deleted apps in the results.
    :param _builtins.str label: Searches for applications whose label or name property matches this value exactly.
    :param _builtins.str label_prefix: Searches for applications whose label or name property begins with this value. **Warning:** This might not work as intended and will be removed in the future release. Use `q` instead.
    :param _builtins.str q: Searches for apps with name or label properties that starts with the `q` value.
    :param _builtins.bool use_optimization: Specifies whether to use query optimization. If you specify `useOptimization=true` in the request query, the response contains a subset of app instance properties.
    """
    __args__ = dict()
    __args__['activeOnly'] = active_only
    __args__['includeNonDeleted'] = include_non_deleted
    __args__['label'] = label
    __args__['labelPrefix'] = label_prefix
    __args__['q'] = q
    __args__['useOptimization'] = use_optimization
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getApps:getApps', __args__, opts=opts, typ=GetAppsResult).value

    return AwaitableGetAppsResult(
        active_only=pulumi.get(__ret__, 'active_only'),
        apps=pulumi.get(__ret__, 'apps'),
        id=pulumi.get(__ret__, 'id'),
        include_non_deleted=pulumi.get(__ret__, 'include_non_deleted'),
        label=pulumi.get(__ret__, 'label'),
        label_prefix=pulumi.get(__ret__, 'label_prefix'),
        q=pulumi.get(__ret__, 'q'),
        use_optimization=pulumi.get(__ret__, 'use_optimization'))
def get_apps_output(active_only: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                    include_non_deleted: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                    label: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    label_prefix: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    q: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                    use_optimization: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAppsResult]:
    """
    Use this data source to access information about an existing resource.

    :param _builtins.bool active_only: Search only active applications.
    :param _builtins.bool include_non_deleted: Specifies whether to include non-active, but not deleted apps in the results.
    :param _builtins.str label: Searches for applications whose label or name property matches this value exactly.
    :param _builtins.str label_prefix: Searches for applications whose label or name property begins with this value. **Warning:** This might not work as intended and will be removed in the future release. Use `q` instead.
    :param _builtins.str q: Searches for apps with name or label properties that starts with the `q` value.
    :param _builtins.bool use_optimization: Specifies whether to use query optimization. If you specify `useOptimization=true` in the request query, the response contains a subset of app instance properties.
    """
    __args__ = dict()
    __args__['activeOnly'] = active_only
    __args__['includeNonDeleted'] = include_non_deleted
    __args__['label'] = label
    __args__['labelPrefix'] = label_prefix
    __args__['q'] = q
    __args__['useOptimization'] = use_optimization
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getApps:getApps', __args__, opts=opts, typ=GetAppsResult)
    return __ret__.apply(lambda __response__: GetAppsResult(
        active_only=pulumi.get(__response__, 'active_only'),
        apps=pulumi.get(__response__, 'apps'),
        id=pulumi.get(__response__, 'id'),
        include_non_deleted=pulumi.get(__response__, 'include_non_deleted'),
        label=pulumi.get(__response__, 'label'),
        label_prefix=pulumi.get(__response__, 'label_prefix'),
        q=pulumi.get(__response__, 'q'),
        use_optimization=pulumi.get(__response__, 'use_optimization')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetHookKeyResult',
    'AwaitableGetHookKeyResult',
    'get_hook_key',
    'get_hook_key_output',
]

@pulumi.output_type
class GetHookKeyResult:
    """
    A collection of values returned by getHookKey.
    """
    def __init__(__self__, created=None, id=None, is_used=None, key_id=None, last_updated=None, name=None):
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_used and not isinstance(is_used, bool):
            raise TypeError("Expected argument 'is_used' to be a bool")
        pulumi.set(__self__, "is_used", is_used)
        if key_id and not isinstance(key_id, str):
            raise TypeError("Expected argument 'key_id' to be a str")
        pulumi.set(__self__, "key_id", key_id)
        if last_updated and not isinstance(last_updated, str):
            raise TypeError("Expected argument 'last_updated' to be a str")
        pulumi.set(__self__, "last_updated", last_updated)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        """
        The date and time the Hook Key was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of the Hook Key.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isUsed")
    def is_used(self) -> _builtins.bool:
        """
        Whether the Hook Key is currently being used.
        """
        return pulumi.get(self, "is_used")

    @_builtins.property
    @pulumi.getter(name="keyId")
    def key_id(self) -> _builtins.str:
        """
        The alias of the public key that can be used to retrieve the public key data.
        """
        return pulumi.get(self, "key_id")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> _builtins.str:
        """
        The date and time the Hook Key was last updated.
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")


class AwaitableGetHookKeyResult(GetHookKeyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetHookKeyResult(
            created=self.created,
            id=self.id,
            is_used=self.is_used,
            key_id=self.key_id,
            last_updated=self.last_updated,
            name=self.name)


def get_hook_key(id: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetHookKeyResult:
    """
    Use Key Management to create and manage JSON Web Keys (JWKS) that support OAuth 2.0 client authentication. The key is composed of a public and private key pair. The private key signs the JSON Web Token (JWT) and the public key validates it on the client side.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    # Get hook key by ID
    example = okta.get_hook_key(id="abcdefghij0123456789")
    ```


    :param _builtins.str id: The unique identifier of the Hook Key.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getHookKey:getHookKey', __args__, opts=opts, typ=GetHookKeyResult).value

    return AwaitableGetHookKeyResult(
        created=pulumi.get(__ret__, 'created'),
        id=pulumi.get(__ret__, 'id'),
        is_used=pulumi.get(__ret__, 'is_used'),
        key_id=pulumi.get(__ret__, 'key_id'),
        last_updated=pulumi.get(__ret__, 'last_updated'),
        name=pulumi.get(__ret__, 'name'))
def get_hook_key_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetHookKeyResult]:
    """
    Use Key Management to create and manage JSON Web Keys (JWKS) that support OAuth 2.0 client authentication. The key is composed of a public and private key pair. The private key signs the JSON Web Token (JWT) and the public key validates it on the client side.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    # Get hook key by ID
    example = okta.get_hook_key(id="abcdefghij0123456789")
    ```


    :param _builtins.str id: The unique identifier of the Hook Key.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getHookKey:getHookKey', __args__, opts=opts, typ=GetHookKeyResult)
    return __ret__.apply(lambda __response__: GetHookKeyResult(
        created=pulumi.get(__response__, 'created'),
        id=pulumi.get(__response__, 'id'),
        is_used=pulumi.get(__response__, 'is_used'),
        key_id=pulumi.get(__response__, 'key_id'),
        last_updated=pulumi.get(__response__, 'last_updated'),
        name=pulumi.get(__response__, 'name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['RateLimitWarningThresholdPercentageArgs', 'RateLimitWarningThresholdPercentage']

@pulumi.input_type
class RateLimitWarningThresholdPercentageArgs:
    def __init__(__self__, *,
                 warning_threshold: pulumi.Input[_builtins.int]):
        """
        The set of arguments for constructing a RateLimitWarningThresholdPercentage resource.
        :param pulumi.Input[_builtins.int] warning_threshold: The threshold value (percentage) of a rate limit that, when exceeded, triggers a warning notification. By default, this value is 90 for Workforce orgs and 60 for CIAM orgs.
        """
        pulumi.set(__self__, "warning_threshold", warning_threshold)

    @_builtins.property
    @pulumi.getter(name="warningThreshold")
    def warning_threshold(self) -> pulumi.Input[_builtins.int]:
        """
        The threshold value (percentage) of a rate limit that, when exceeded, triggers a warning notification. By default, this value is 90 for Workforce orgs and 60 for CIAM orgs.
        """
        return pulumi.get(self, "warning_threshold")

    @warning_threshold.setter
    def warning_threshold(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "warning_threshold", value)


@pulumi.input_type
class _RateLimitWarningThresholdPercentageState:
    def __init__(__self__, *,
                 warning_threshold: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering RateLimitWarningThresholdPercentage resources.
        :param pulumi.Input[_builtins.int] warning_threshold: The threshold value (percentage) of a rate limit that, when exceeded, triggers a warning notification. By default, this value is 90 for Workforce orgs and 60 for CIAM orgs.
        """
        if warning_threshold is not None:
            pulumi.set(__self__, "warning_threshold", warning_threshold)

    @_builtins.property
    @pulumi.getter(name="warningThreshold")
    def warning_threshold(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The threshold value (percentage) of a rate limit that, when exceeded, triggers a warning notification. By default, this value is 90 for Workforce orgs and 60 for CIAM orgs.
        """
        return pulumi.get(self, "warning_threshold")

    @warning_threshold.setter
    def warning_threshold(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "warning_threshold", value)


@pulumi.type_token("okta:index/rateLimitWarningThresholdPercentage:RateLimitWarningThresholdPercentage")
class RateLimitWarningThresholdPercentage(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 warning_threshold: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Rate limit warning threshold percentage provides operations to manage threshold for warning notifications when the API's rate limit is exceeded.
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.RateLimitWarningThresholdPercentage("example", warning_threshold=90)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/rateLimitWarningThresholdPercentage:RateLimitWarningThresholdPercentage example .
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] warning_threshold: The threshold value (percentage) of a rate limit that, when exceeded, triggers a warning notification. By default, this value is 90 for Workforce orgs and 60 for CIAM orgs.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RateLimitWarningThresholdPercentageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Rate limit warning threshold percentage provides operations to manage threshold for warning notifications when the API's rate limit is exceeded.
        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.RateLimitWarningThresholdPercentage("example", warning_threshold=90)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/rateLimitWarningThresholdPercentage:RateLimitWarningThresholdPercentage example .
        ```

        :param str resource_name: The name of the resource.
        :param RateLimitWarningThresholdPercentageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RateLimitWarningThresholdPercentageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 warning_threshold: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RateLimitWarningThresholdPercentageArgs.__new__(RateLimitWarningThresholdPercentageArgs)

            if warning_threshold is None and not opts.urn:
                raise TypeError("Missing required property 'warning_threshold'")
            __props__.__dict__["warning_threshold"] = warning_threshold
        super(RateLimitWarningThresholdPercentage, __self__).__init__(
            'okta:index/rateLimitWarningThresholdPercentage:RateLimitWarningThresholdPercentage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            warning_threshold: Optional[pulumi.Input[_builtins.int]] = None) -> 'RateLimitWarningThresholdPercentage':
        """
        Get an existing RateLimitWarningThresholdPercentage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] warning_threshold: The threshold value (percentage) of a rate limit that, when exceeded, triggers a warning notification. By default, this value is 90 for Workforce orgs and 60 for CIAM orgs.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RateLimitWarningThresholdPercentageState.__new__(_RateLimitWarningThresholdPercentageState)

        __props__.__dict__["warning_threshold"] = warning_threshold
        return RateLimitWarningThresholdPercentage(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="warningThreshold")
    def warning_threshold(self) -> pulumi.Output[_builtins.int]:
        """
        The threshold value (percentage) of a rate limit that, when exceeded, triggers a warning notification. By default, this value is 90 for Workforce orgs and 60 for CIAM orgs.
        """
        return pulumi.get(self, "warning_threshold")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRequestConditionResult',
    'AwaitableGetRequestConditionResult',
    'get_request_condition',
    'get_request_condition_output',
]

@pulumi.output_type
class GetRequestConditionResult:
    """
    A collection of values returned by getRequestCondition.
    """
    def __init__(__self__, access_scope_settings=None, created=None, created_by=None, id=None, last_updated=None, last_updated_by=None, name=None, priority=None, requester_settings=None, resource_id=None, status=None):
        if access_scope_settings and not isinstance(access_scope_settings, dict):
            raise TypeError("Expected argument 'access_scope_settings' to be a dict")
        pulumi.set(__self__, "access_scope_settings", access_scope_settings)
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_updated and not isinstance(last_updated, str):
            raise TypeError("Expected argument 'last_updated' to be a str")
        pulumi.set(__self__, "last_updated", last_updated)
        if last_updated_by and not isinstance(last_updated_by, str):
            raise TypeError("Expected argument 'last_updated_by' to be a str")
        pulumi.set(__self__, "last_updated_by", last_updated_by)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if priority and not isinstance(priority, int):
            raise TypeError("Expected argument 'priority' to be a int")
        pulumi.set(__self__, "priority", priority)
        if requester_settings and not isinstance(requester_settings, dict):
            raise TypeError("Expected argument 'requester_settings' to be a dict")
        pulumi.set(__self__, "requester_settings", requester_settings)
        if resource_id and not isinstance(resource_id, str):
            raise TypeError("Expected argument 'resource_id' to be a str")
        pulumi.set(__self__, "resource_id", resource_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="accessScopeSettings")
    def access_scope_settings(self) -> Optional['outputs.GetRequestConditionAccessScopeSettingsResult']:
        return pulumi.get(self, "access_scope_settings")

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        """
        The date and time when the request condition was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.str:
        """
        The id of the user who created the request condition.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Request condition id.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> _builtins.str:
        """
        The date and time when the request condition was last updated.
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> _builtins.str:
        """
        The id of the user who last updated the request condition.
        """
        return pulumi.get(self, "last_updated_by")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the request condition.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> _builtins.int:
        """
        The priority of the request condition. Lower numbers indicate higher priority.
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter(name="requesterSettings")
    def requester_settings(self) -> Optional['outputs.GetRequestConditionRequesterSettingsResult']:
        return pulumi.get(self, "requester_settings")

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> _builtins.str:
        """
        The id of the resource in Okta ID format.
        """
        return pulumi.get(self, "resource_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Status indicates if this condition is active or not. Default status is INACTIVE. Enum: `ACTIVE`, `INACTIVE`, `DELETED`, `INVALID`.
        """
        return pulumi.get(self, "status")


class AwaitableGetRequestConditionResult(GetRequestConditionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRequestConditionResult(
            access_scope_settings=self.access_scope_settings,
            created=self.created,
            created_by=self.created_by,
            id=self.id,
            last_updated=self.last_updated,
            last_updated_by=self.last_updated_by,
            name=self.name,
            priority=self.priority,
            requester_settings=self.requester_settings,
            resource_id=self.resource_id,
            status=self.status)


def get_request_condition(access_scope_settings: Optional[Union['GetRequestConditionAccessScopeSettingsArgs', 'GetRequestConditionAccessScopeSettingsArgsDict']] = None,
                          id: Optional[_builtins.str] = None,
                          requester_settings: Optional[Union['GetRequestConditionRequesterSettingsArgs', 'GetRequestConditionRequesterSettingsArgsDict']] = None,
                          resource_id: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRequestConditionResult:
    """
    Retrieves a resource request condition

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_request_condition(id="<request_condition_id>",
        resource_id="<resource_id>")
    ```


    :param _builtins.str id: Request condition id.
    :param _builtins.str resource_id: The id of the resource in Okta ID format.
    """
    __args__ = dict()
    __args__['accessScopeSettings'] = access_scope_settings
    __args__['id'] = id
    __args__['requesterSettings'] = requester_settings
    __args__['resourceId'] = resource_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getRequestCondition:getRequestCondition', __args__, opts=opts, typ=GetRequestConditionResult).value

    return AwaitableGetRequestConditionResult(
        access_scope_settings=pulumi.get(__ret__, 'access_scope_settings'),
        created=pulumi.get(__ret__, 'created'),
        created_by=pulumi.get(__ret__, 'created_by'),
        id=pulumi.get(__ret__, 'id'),
        last_updated=pulumi.get(__ret__, 'last_updated'),
        last_updated_by=pulumi.get(__ret__, 'last_updated_by'),
        name=pulumi.get(__ret__, 'name'),
        priority=pulumi.get(__ret__, 'priority'),
        requester_settings=pulumi.get(__ret__, 'requester_settings'),
        resource_id=pulumi.get(__ret__, 'resource_id'),
        status=pulumi.get(__ret__, 'status'))
def get_request_condition_output(access_scope_settings: Optional[pulumi.Input[Optional[Union['GetRequestConditionAccessScopeSettingsArgs', 'GetRequestConditionAccessScopeSettingsArgsDict']]]] = None,
                                 id: Optional[pulumi.Input[_builtins.str]] = None,
                                 requester_settings: Optional[pulumi.Input[Optional[Union['GetRequestConditionRequesterSettingsArgs', 'GetRequestConditionRequesterSettingsArgsDict']]]] = None,
                                 resource_id: Optional[pulumi.Input[_builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRequestConditionResult]:
    """
    Retrieves a resource request condition

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_request_condition(id="<request_condition_id>",
        resource_id="<resource_id>")
    ```


    :param _builtins.str id: Request condition id.
    :param _builtins.str resource_id: The id of the resource in Okta ID format.
    """
    __args__ = dict()
    __args__['accessScopeSettings'] = access_scope_settings
    __args__['id'] = id
    __args__['requesterSettings'] = requester_settings
    __args__['resourceId'] = resource_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getRequestCondition:getRequestCondition', __args__, opts=opts, typ=GetRequestConditionResult)
    return __ret__.apply(lambda __response__: GetRequestConditionResult(
        access_scope_settings=pulumi.get(__response__, 'access_scope_settings'),
        created=pulumi.get(__response__, 'created'),
        created_by=pulumi.get(__response__, 'created_by'),
        id=pulumi.get(__response__, 'id'),
        last_updated=pulumi.get(__response__, 'last_updated'),
        last_updated_by=pulumi.get(__response__, 'last_updated_by'),
        name=pulumi.get(__response__, 'name'),
        priority=pulumi.get(__response__, 'priority'),
        requester_settings=pulumi.get(__response__, 'requester_settings'),
        resource_id=pulumi.get(__response__, 'resource_id'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetPrincipalEntitlementsResult',
    'AwaitableGetPrincipalEntitlementsResult',
    'get_principal_entitlements',
    'get_principal_entitlements_output',
]

@pulumi.output_type
class GetPrincipalEntitlementsResult:
    """
    A collection of values returned by getPrincipalEntitlements.
    """
    def __init__(__self__, datas=None, id=None, parent=None, target_principal=None):
        if datas and not isinstance(datas, list):
            raise TypeError("Expected argument 'datas' to be a list")
        pulumi.set(__self__, "datas", datas)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if parent and not isinstance(parent, dict):
            raise TypeError("Expected argument 'parent' to be a dict")
        pulumi.set(__self__, "parent", parent)
        if target_principal and not isinstance(target_principal, dict):
            raise TypeError("Expected argument 'target_principal' to be a dict")
        pulumi.set(__self__, "target_principal", target_principal)

    @_builtins.property
    @pulumi.getter
    def datas(self) -> Optional[Sequence['outputs.GetPrincipalEntitlementsDataResult']]:
        """
        Principal entitlements list.
        """
        return pulumi.get(self, "datas")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> Optional['outputs.GetPrincipalEntitlementsParentResult']:
        """
        Representation of a resource.
        """
        return pulumi.get(self, "parent")

    @_builtins.property
    @pulumi.getter(name="targetPrincipal")
    def target_principal(self) -> Optional['outputs.GetPrincipalEntitlementsTargetPrincipalResult']:
        """
        Representation of a principal.
        """
        return pulumi.get(self, "target_principal")


class AwaitableGetPrincipalEntitlementsResult(GetPrincipalEntitlementsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPrincipalEntitlementsResult(
            datas=self.datas,
            id=self.id,
            parent=self.parent,
            target_principal=self.target_principal)


def get_principal_entitlements(datas: Optional[Sequence[Union['GetPrincipalEntitlementsDataArgs', 'GetPrincipalEntitlementsDataArgsDict']]] = None,
                               parent: Optional[Union['GetPrincipalEntitlementsParentArgs', 'GetPrincipalEntitlementsParentArgsDict']] = None,
                               target_principal: Optional[Union['GetPrincipalEntitlementsTargetPrincipalArgs', 'GetPrincipalEntitlementsTargetPrincipalArgsDict']] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPrincipalEntitlementsResult:
    """
    Get the entitlements for a user and resource after evaluating all grants.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_principal_entitlements(parent={
            "external_id": "<resource_id>",
            "type": "<resource_type>",
        },
        target_principal={
            "external_id": "<principal_id>",
            "type": "<principal_type>",
        })
    ```

    ## Required:

    - `external_id` (String) The Okta user's email address.
    - `type` (String) The Okta user id.

    <a id="nestedblock--target_principal"></a>
    ### Nested Schema for `target_principal`
    ## Required:

    - `external_id` (String) The Okta user id.
    - `type` (String) The type of principal. Enum: `OKTA_USER`.

    <a id="nestedblock--data"></a>
    ### Nested Schema for `data`
    ## Required:

    - `parent` (Object) Representation of a resource. (see below for nested schema)
    - `target_principal` (Object) Representation of a principal. (see below for nested schema)

    ## Optional:

    - `data_type` (String) The data type of the entitlement property. Enum: `array`, `string`.
    - `description` (String) The Okta user id.
    - `external_value` (String) The type of principal. Enum: `OKTA_USER`.
    - `id` (String) The unique identifier of the entitlement.
    - `multi_value` (Boolean) Indicates if the entitlement is multi-valued.
    - `name` (String) The name of the entitlement.
    - `parent_resource_orn` (String) The Okta app instance, in ORN format.
    - `required` (Boolean) Indicates if the entitlement is required.
    - `target_principal_orn` (String) The Okta user id, in ORN format.
    - `values` (List of Objects) The values of the entitlement. (see below for nested schema)

    <a id="nestedblock--values"></a>
    ### Nested Schema for `values`
    - `description` (String) The description of the value.
    - `external_id` (String) The external ID of the value.
    - `external_value` (String) The value of an entitlement property value.
    - `id` (String) The unique identifier of the value.
    - `name` (String) The name of the value.


    :param Sequence[Union['GetPrincipalEntitlementsDataArgs', 'GetPrincipalEntitlementsDataArgsDict']] datas: Principal entitlements list.
    :param Union['GetPrincipalEntitlementsParentArgs', 'GetPrincipalEntitlementsParentArgsDict'] parent: Representation of a resource.
    :param Union['GetPrincipalEntitlementsTargetPrincipalArgs', 'GetPrincipalEntitlementsTargetPrincipalArgsDict'] target_principal: Representation of a principal.
    """
    __args__ = dict()
    __args__['datas'] = datas
    __args__['parent'] = parent
    __args__['targetPrincipal'] = target_principal
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getPrincipalEntitlements:getPrincipalEntitlements', __args__, opts=opts, typ=GetPrincipalEntitlementsResult).value

    return AwaitableGetPrincipalEntitlementsResult(
        datas=pulumi.get(__ret__, 'datas'),
        id=pulumi.get(__ret__, 'id'),
        parent=pulumi.get(__ret__, 'parent'),
        target_principal=pulumi.get(__ret__, 'target_principal'))
def get_principal_entitlements_output(datas: Optional[pulumi.Input[Optional[Sequence[Union['GetPrincipalEntitlementsDataArgs', 'GetPrincipalEntitlementsDataArgsDict']]]]] = None,
                                      parent: Optional[pulumi.Input[Optional[Union['GetPrincipalEntitlementsParentArgs', 'GetPrincipalEntitlementsParentArgsDict']]]] = None,
                                      target_principal: Optional[pulumi.Input[Optional[Union['GetPrincipalEntitlementsTargetPrincipalArgs', 'GetPrincipalEntitlementsTargetPrincipalArgsDict']]]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPrincipalEntitlementsResult]:
    """
    Get the entitlements for a user and resource after evaluating all grants.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_principal_entitlements(parent={
            "external_id": "<resource_id>",
            "type": "<resource_type>",
        },
        target_principal={
            "external_id": "<principal_id>",
            "type": "<principal_type>",
        })
    ```

    ## Required:

    - `external_id` (String) The Okta user's email address.
    - `type` (String) The Okta user id.

    <a id="nestedblock--target_principal"></a>
    ### Nested Schema for `target_principal`
    ## Required:

    - `external_id` (String) The Okta user id.
    - `type` (String) The type of principal. Enum: `OKTA_USER`.

    <a id="nestedblock--data"></a>
    ### Nested Schema for `data`
    ## Required:

    - `parent` (Object) Representation of a resource. (see below for nested schema)
    - `target_principal` (Object) Representation of a principal. (see below for nested schema)

    ## Optional:

    - `data_type` (String) The data type of the entitlement property. Enum: `array`, `string`.
    - `description` (String) The Okta user id.
    - `external_value` (String) The type of principal. Enum: `OKTA_USER`.
    - `id` (String) The unique identifier of the entitlement.
    - `multi_value` (Boolean) Indicates if the entitlement is multi-valued.
    - `name` (String) The name of the entitlement.
    - `parent_resource_orn` (String) The Okta app instance, in ORN format.
    - `required` (Boolean) Indicates if the entitlement is required.
    - `target_principal_orn` (String) The Okta user id, in ORN format.
    - `values` (List of Objects) The values of the entitlement. (see below for nested schema)

    <a id="nestedblock--values"></a>
    ### Nested Schema for `values`
    - `description` (String) The description of the value.
    - `external_id` (String) The external ID of the value.
    - `external_value` (String) The value of an entitlement property value.
    - `id` (String) The unique identifier of the value.
    - `name` (String) The name of the value.


    :param Sequence[Union['GetPrincipalEntitlementsDataArgs', 'GetPrincipalEntitlementsDataArgsDict']] datas: Principal entitlements list.
    :param Union['GetPrincipalEntitlementsParentArgs', 'GetPrincipalEntitlementsParentArgsDict'] parent: Representation of a resource.
    :param Union['GetPrincipalEntitlementsTargetPrincipalArgs', 'GetPrincipalEntitlementsTargetPrincipalArgsDict'] target_principal: Representation of a principal.
    """
    __args__ = dict()
    __args__['datas'] = datas
    __args__['parent'] = parent
    __args__['targetPrincipal'] = target_principal
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getPrincipalEntitlements:getPrincipalEntitlements', __args__, opts=opts, typ=GetPrincipalEntitlementsResult)
    return __ret__.apply(lambda __response__: GetPrincipalEntitlementsResult(
        datas=pulumi.get(__response__, 'datas'),
        id=pulumi.get(__response__, 'id'),
        parent=pulumi.get(__response__, 'parent'),
        target_principal=pulumi.get(__response__, 'target_principal')))
